@@ -7,9 +7,9 @@ Usage::
 
     ```python
     import boto3
-    from mypy_boto3_sagemaker_featurestore_runtime import SagemakerFeatureStoreRuntimeClient
+    from mypy_boto3_sagemaker_featurestore_runtime import SageMakerFeatureStoreRuntimeClient
 
-    client: SagemakerFeatureStoreRuntimeClient = boto3.client("sagemaker-featurestore-runtime")
+    client: SageMakerFeatureStoreRuntimeClient = boto3.client("sagemaker-featurestore-runtime")
     ```
 """
 from typing import Any, Dict, List, Type
@@ -18,7 +18,7 @@ from botocore.client import ClientMeta
 
 from .type_defs import FeatureValueTypeDef, GetRecordResponseTypeDef
 
-__all__ = ("SagemakerFeatureStoreRuntimeClient",)
+__all__ = ("SageMakerFeatureStoreRuntimeClient",)
 
 
 class BotocoreClientError(BaseException):
@@ -38,9 +38,9 @@ class Exceptions:
     ValidationError: Type[BotocoreClientError]
 
 
-class SagemakerFeatureStoreRuntimeClient:
+class SageMakerFeatureStoreRuntimeClient:
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.78/reference/services/sagemaker-featurestore-runtime.html#SagemakerFeatureStoreRuntime.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.80/reference/services/sagemaker-featurestore-runtime.html#SageMakerFeatureStoreRuntime.Client)
     [Show boto3-stubs documentation](./client.md)
     """
 
@@ -49,7 +49,7 @@ class SagemakerFeatureStoreRuntimeClient:
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.78/reference/services/sagemaker-featurestore-runtime.html#SagemakerFeatureStoreRuntime.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.80/reference/services/sagemaker-featurestore-runtime.html#SageMakerFeatureStoreRuntime.Client.can_paginate)
         [Show boto3-stubs documentation](./client.md#can_paginate)
         """
 
@@ -57,7 +57,7 @@ class SagemakerFeatureStoreRuntimeClient:
         self, FeatureGroupName: str, RecordIdentifierValueAsString: str, EventTime: str
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.78/reference/services/sagemaker-featurestore-runtime.html#SagemakerFeatureStoreRuntime.Client.delete_record)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.80/reference/services/sagemaker-featurestore-runtime.html#SageMakerFeatureStoreRuntime.Client.delete_record)
         [Show boto3-stubs documentation](./client.md#delete_record)
         """
 
@@ -69,7 +69,7 @@ class SagemakerFeatureStoreRuntimeClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.78/reference/services/sagemaker-featurestore-runtime.html#SagemakerFeatureStoreRuntime.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.80/reference/services/sagemaker-featurestore-runtime.html#SageMakerFeatureStoreRuntime.Client.generate_presigned_url)
         [Show boto3-stubs documentation](./client.md#generate_presigned_url)
         """
 
@@ -80,12 +80,12 @@ class SagemakerFeatureStoreRuntimeClient:
         FeatureNames: List[str] = None,
     ) -> GetRecordResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.78/reference/services/sagemaker-featurestore-runtime.html#SagemakerFeatureStoreRuntime.Client.get_record)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.80/reference/services/sagemaker-featurestore-runtime.html#SageMakerFeatureStoreRuntime.Client.get_record)
         [Show boto3-stubs documentation](./client.md#get_record)
         """
 
     def put_record(self, FeatureGroupName: str, Record: List["FeatureValueTypeDef"]) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.78/reference/services/sagemaker-featurestore-runtime.html#SagemakerFeatureStoreRuntime.Client.put_record)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.80/reference/services/sagemaker-featurestore-runtime.html#SageMakerFeatureStoreRuntime.Client.put_record)
         [Show boto3-stubs documentation](./client.md#put_record)
         """
